@@ -64,9 +64,11 @@ from datalad.tests.utils_pytest import (
     ok_,
     ok_file_has_content,
     ok_startswith,
+    on_travis,
     patch_config,
     serve_path_via_http,
     set_date,
+    skip_if,
     skip_if_adjusted_branch,
     skip_if_no_network,
     skip_if_on_windows,
@@ -304,6 +306,7 @@ def test_clone_isnot_recursive(path_src=None, path_nr=None, path_r=None):
         {'subm 1', '2'})
 
 
+@skip_if(on_travis)  # xfails -- stalls, https://github.com/datalad/datalad/issues/6845
 @with_tempfile
 @with_tempfile
 def test_clone_into_dataset(source_path=None, top_path=None):
