@@ -314,7 +314,7 @@ class Save(Interface):
                         # calls
                         paths=None,
                         # prevent whining of GitRepo
-                        git=True if not hasattr(ds.repo, 'uuid')
+                        git=True if not hasattr(pds_repo, 'uuid')
                         else to_git,
                         # we are supplying the full status already, do not
                         # detect anything else
