@@ -33,6 +33,8 @@ from datalad.tests.utils_pytest import (
     eq_,
     ok_file_has_content,
     ok_generator,
+    on_nfs,
+    on_travis,
     on_windows,
     skip_if,
     swallow_outputs,
@@ -100,6 +102,7 @@ def check_decompress_file(leading_directories, path=None):
         eq_(f.read(), '3 load')
 
 
+@pytest.mark.xfail(on_travis and on_nfs, reason="https://github.com/datalad/datalad/issues/4496")
 @pytest.mark.parametrize("leading", [None, 'strip'])
 def test_decompress_file(leading):
     return check_decompress_file(leading)
