@@ -36,7 +36,10 @@ from datalad import utils
 from datalad.consts import ARCHIVES_TEMP_DIR
 from datalad.dochelpers import borrowkwargs
 
-from datalad.support.external_versions import external_versions
+from datalad.support.external_versions import (
+    external_versions,
+    get_rsync_version,
+)
 from datalad.support.keyring_ import MemoryKeyring
 from datalad.support.network import RI
 from datalad.support.vcr_ import *
@@ -50,6 +53,8 @@ _TEMP_PATHS_CLONES = set()
 
 # Additional indicators
 on_travis = bool(os.environ.get('TRAVIS', False))
+on_appveyor = bool(os.environ.get('APPVEYOR', False))
+on_nfs = 'nfs' in os.getenv('TMPDIR', '')
 
 if external_versions["cmd:git"] >= "2.28":
     # The specific value here doesn't matter, but it should not be the default
@@ -906,7 +911,7 @@ def with_tempfile(t, **tkwargs):
     ::
 
         @with_tempfile
-        def test_write(tfile):
+        def test_write(tfile=None):
             open(tfile, 'w').write('silly test')
     """
 
@@ -1122,6 +1127,16 @@ def with_sameas_remote(func, autoenabled=False):
            '8.20200522' < external_versions['cmd:annex'] < '8.20200720':
             pytest.skip("Test known to hang")
 
+        # A fix in rsync 3.2.4 broke compatibility with older annex versions.
+        # To make things a bit more complicated, ubuntu pulled that fix into
+        # their rsync package for 3.1.3-8.
+        # Issue: gh-7320
+        rsync_ver = get_rsync_version()
+        rsync_fixed = rsync_ver >= "3.1.3-8ubuntu" or rsync_ver >= "3.2.4"
+        if rsync_fixed and external_versions['cmd:annex'] < "10.20220504":
+            pytest.skip(f"rsync {rsync_ver} and git-annex "
+                        f"{external_versions['cmd:annex']} incompatible")
+
         sr_path, repo_path = args[-2:]
         fn_args = args[:-2]
         repo = AnnexRepo(repo_path)
@@ -1661,7 +1676,8 @@ def get_convoluted_situation(path, repocls=AnnexRepo):
     #        'reason unknown')
     repo = repocls(path, create=True)
     # use create(force) to get an ID and config into the empty repo
-    ds = Dataset(path).create(force=True, **ckwa)
+    # Pass explicit `annex` to ensure that GitRepo does get .noannex
+    ds = Dataset(path).create(force=True, annex=repocls is AnnexRepo, **ckwa)
     # base content
     create_tree(
         ds.path,
